import React, { isValidElement } from 'react';
import { View, StyleSheet, Text } from 'react-native';
import { Theme } from '../../components/Styles/theme';
import Icon from '../Icon';
import Touchable from '../Touchable';
const Cell = props => {
    const { title, titleStyle = {}, label, border = true, centerRightText = false, rightContent, isLink = false, rightIconName = 'right', rightIconSize = 24, rightIconColor = '#7f7f7f', style, onPress, renderLeftIcon, } = props;
    return (React.createElement(Touchable, { style: [styles.container, border && styles.border, style], underlayColor: Theme.fillBody, onPress: onPress },
        React.createElement(React.Fragment, null,
            React.createElement(View, { style: styles.left },
                React.createElement(View, { style: styles.titleWrap },
                    renderLeftIcon ? React.createElement(View, { style: styles.iconWrap }, renderLeftIcon()) : null,
                    React.createElement(Text, { style: [styles.titleText, titleStyle] }, title)),
                !!label && (React.createElement(View, { style: styles.titleLabelWrap },
                    React.createElement(Text, { numberOfLines: 1, style: styles.titleLabel }, label)))),
            React.createElement(View, { style: [styles.right, { alignSelf: centerRightText ? 'center' : 'flex-start' }] },
                !!rightContent &&
                    (isValidElement(rightContent) ? (rightContent) : (React.createElement(View, { style: styles.rightContent },
                        React.createElement(Text, { style: styles.rightContentText, numberOfLines: 1, ellipsizeMode: "tail" }, rightContent)))),
                isLink && React.createElement(Icon, { name: rightIconName, size: rightIconSize, color: rightIconColor })))));
};
const styles = StyleSheet.create({
    container: {
        flexDirection: 'row',
        alignItems: 'center',
        paddingVertical: 12,
        paddingHorizontal: 10,
    },
    border: {
        borderBottomColor: Theme.borderLightColor,
        borderBottomWidth: 0.5,
    },
    left: {
        flexBasis: '50%',
    },
    titleWrap: {
        flexDirection: 'row',
        alignItems: 'center',
    },
    iconWrap: {
        marginRight: 6,
    },
    titleText: {
        fontSize: 16,
        color: Theme.colorTextParagraph,
    },
    titleLabelWrap: {
        marginTop: 4,
    },
    titleLabel: {
        fontSize: 12,
        color: Theme.colorTextCaption,
    },
    right: {
        flexBasis: '50%',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'flex-end',
    },
    rightContent: {
        flex: 1,
        flexDirection: 'row',
        justifyContent: 'flex-end',
    },
    rightContentText: {
        fontSize: 14,
        color: Theme.colorTextGray,
    },
});
export default Cell;
